@@ -1,13 +1,15 @@
-#!/usr/bin/perl
+#!@PERL@
 
 # fakeldd
 #
 # Replacement for ldd with usage of objdump
 #
-# (c) 2003-2010 Piotr Roszatycki <dexter@debian.org>, LGPL
+# (c) 2003-2010, 2013, 2016 Piotr Roszatycki <dexter@debian.org>, LGPL
 
 use strict;
 
+$ENV{LANG} = $ENV{LC_ALL} = 'C';
+
 my @Libs = ();
 my %Libs = ();
 
@@ -18,6 +20,10 @@ my $Format = '';
 my $Ldsodir = "/lib";
 my @Ld_Library_Path = qw(/usr/lib /lib /usr/lib32 /lib32 /usr/lib64 /lib64);
 
+my $Cwd = `pwd`;
+chomp $Cwd;
+
+my $Base = defined $ENV{FAKECHROOT_BASE_ORIG} ? $ENV{FAKECHROOT_BASE_ORIG} : '';
 
 sub ldso {
     my ($lib) = @_;
@@ -26,7 +32,7 @@ sub ldso {
 
     my $path;
 
-    if ($lib =~ /^\//) {
+    if ($lib =~ m{^/}) {
         $path = $lib;
     }
     else {
@@ -53,6 +59,7 @@ sub ldso {
 
     push @Libs, $lib;
     if (-f $path) {
+        $path =~ s{^\Q$Base/\E}{} if $Base;
         $Libs{$lib} = $path;
         objdump($path);
     }
@@ -63,8 +70,11 @@ sub objdump {
     my (@files) = @_;
 
     foreach my $file (@files) {
+        $file = $file =~ m{^/} ? "$Base$file" : "$Cwd/$file";
+
         local *PIPE;
         open PIPE, "objdump -p '$file' 2>/dev/null |";
+
         while (my $line = <PIPE>) {
             $line =~ s/^\s+//;
 
@@ -73,6 +83,13 @@ sub objdump {
                     $Format = $1;
 
                     if ($^O eq 'linux') {
+                        if ($Format =~ /^elf64-(x86-64|sparc)$/) {
+                            $Ldsodir = "/lib64";
+                        }
+                        elsif ($Format =~ /^elf32-x86-64$/) {
+                            $Ldsodir = "/libx32";
+                        }
+
                         if ($Format =~ /^elf64-/) {
                             push @Libs, 'linux-vdso.so.1';
                             $Libs{'linux-vdso.so.1'} = '';
@@ -83,7 +100,7 @@ sub objdump {
                         }
                     }
 
-                    foreach my $lib (split /:/, $ENV{LD_PRELOAD}||'') {
+                    foreach my $lib (split /[:\s]/, $ENV{LD_PRELOAD}||'') {
                         ldso($lib);
                     }
                 }
@@ -101,7 +118,6 @@ sub objdump {
             if ($needed =~ /^ld(-linux)?(\.|-)/) {
                 $needed = "$Ldsodir/$needed";
             }
-
             ldso($needed);
         }
         close PIPE;
@@ -111,6 +127,7 @@ sub objdump {
 
 sub load_ldsoconf {
     my ($file) = @_;
+    my @paths;
 
     local *FH;
     open FH, $file;
@@ -127,9 +144,11 @@ sub load_ldsoconf {
             next;
         }
 
-        unshift @Ld_Library_Path, $line;
+        push @paths, $line;
     }
     close FH;
+
+    unshift @Ld_Library_Path, @paths;
 }
 
 
@@ -141,7 +160,7 @@ MAIN: {
         exit 1;
     }
 
-    if (not `which objdump`) {
+    if (not `sh -c 'command -v objdump'`) {
         print STDERR "fakeldd: objdump: command not found: install binutils package\n";
         exit 1;
     }
@@ -163,8 +182,10 @@ MAIN: {
             print "$file:\n";
         }
 
-        if (not -f $file) {
-            print STDERR "ldd: $file: No such file or directory\n";
+        my $file_in_chroot = $file =~ m{^/} ? "$Base$file" : "$file";
+
+        if (not -f $file_in_chroot) {
+            print STDERR "fakeldd: $file: No such file or directory\n";
             $Status = 1;
             next;
         }
@@ -181,11 +202,14 @@ MAIN: {
 
         my $address = '0x' . '0' x ($Format =~ /^elf64-/ ? 16 : 8);
 
+        my %seen;
+
         foreach my $lib (@Libs) {
-            if ($lib =~ /^\//) {
+            next if $seen{$lib}++;
+            if ($lib =~ m{^/} or $lib =~ /^linux-/) {
                 printf "\t%s (%s)\n", $lib, $address;
             }
-            elsif (defined $Libs{$lib}) {
+            elsif ($Libs{$lib}) {
                 printf "\t%s => %s (%s)\n", $lib, $Libs{$lib}, $address;
             }
             else {
