@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013, 2015 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,7 @@
 #ifdef HAVE___LXSTAT64
 
 #define _LARGEFILE64_SOURCE
-#define _XOPEN_SOURCE
+#define _XOPEN_SOURCE 500
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -39,12 +39,10 @@ wrapper(__lxstat64, int, (int ver, const char * filename, struct stat64 * buf))
 {
     debug("__lxstat64(%d, \"%s\", &buf)", ver, filename);
 
-    if (!fakechroot_localdir(filename)) {
-        if (filename != NULL) {
-            char abs_filename[FAKECHROOT_PATH_MAX];
-            rel2abs(filename, abs_filename);
-            filename = abs_filename;
-        }
+    if (filename && !fakechroot_localdir(filename)) {
+        char abs_filename[FAKECHROOT_PATH_MAX];
+        rel2abs(filename, abs_filename);
+        filename = abs_filename;
     }
 
     return __lxstat64_rel(ver, filename, buf);
@@ -64,7 +62,7 @@ LOCAL int __lxstat64_rel(int ver, const char * filename, struct stat64 * buf)
     expand_chroot_rel_path(filename);
     retval = nextcall(__lxstat64)(ver, filename, buf);
     /* deal with http://bugs.debian.org/561991 */
-    if ((buf->st_mode & S_IFMT) == S_IFLNK)
+    if ((retval == 0) && (buf->st_mode & S_IFMT) == S_IFLNK)
         if ((linksize = readlink(orig_filename, tmp, sizeof(tmp)-1)) != -1)
             buf->st_size = linksize;
 
