@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -18,4 +18,13 @@
 */
 
 
+#ifndef ____REALPATH_CHK_H
+#define ____REALPATH_CHK_H
+
+#include <config.h>
+
+#include "libfakechroot.h"
+
 wrapper_proto(__realpath_chk, char *, (const char *, char *, size_t));
+
+#endif
