@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -22,16 +22,19 @@
 
 #ifdef HAVE___XMKNOD
 
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 #include "libfakechroot.h"
 
 
 wrapper(__xmknod, int, (int ver, const char * path, mode_t mode, dev_t * dev))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
-    debug("__xmknod(%d, \"%s\", 0%od, &dev)", ver, path, mode);
-    expand_chroot_path(path, fakechroot_path, fakechroot_buf);
+    debug("__xmknod(%d, \"%s\", 0%o, &dev)", ver, path, mode);
+    expand_chroot_path(path);
     return nextcall(__xmknod)(ver, path, mode, dev);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
