@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013, 2016 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@ wrapper(chdir, int, (const char * path))
         return -1;
     }
     if (fakechroot_base != NULL) {
-        if (strstr(cwd, fakechroot_base) == path) {
+        if (strstr(cwd, fakechroot_base) == cwd) {
             expand_chroot_path(path);
         }
         else {
