@@ -71,10 +71,14 @@ wrapper(chroot, int, (const char * path))
         return -1;
     }
 
-    if (fakechroot_base != NULL && strstr(cwd, fakechroot_base) == fakechroot_base) {
+    if (fakechroot_base != NULL && strstr(cwd, fakechroot_base) == cwd) {
         expand_chroot_path(path);
+        strlcpy(tmp, path, FAKECHROOT_PATH_MAX);
+        dedotdot(tmpptr);
+        path = tmpptr;
     }
     else {
+        size_t tmplen;
         if (*path == '/') {
             expand_chroot_rel_path(path);
             strlcpy(tmp, path, FAKECHROOT_PATH_MAX);
@@ -86,6 +90,15 @@ wrapper(chroot, int, (const char * path))
             dedotdot(tmpptr);
             path = tmpptr;
         }
+        tmplen = strlen(tmpptr);
+        while(tmplen > 1 && tmpptr[tmplen - 1] == '/') {
+            tmpptr[--tmplen] = '\0';
+        }
+    }
+
+    /* Suppress a trailing slash */
+    if ((strlen(tmpptr) > 1) && path[strlen(tmpptr) - 1] == '/') {
+        tmpptr[strlen(tmpptr) - 1] = '\0';
     }
 
     if ((status = STAT(path, &sb)) != 0) {
