@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -22,16 +22,18 @@
 
 #ifdef HAVE_LCHMOD
 
+#include <sys/types.h>
 #include <sys/stat.h>
 #include "libfakechroot.h"
 
 
 wrapper(lchmod, int, (const char * path, mode_t mode))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
-    debug("lchmod(\"%s\", 0%od)", path, mode);
-    expand_chroot_path(path, fakechroot_path, fakechroot_buf);
+    debug("lchmod(\"%s\", 0%o)", path, mode);
+    expand_chroot_path(path);
     return nextcall(lchmod)(path, mode);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
