@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,11 @@
 
 wrapper(mknod, int, (const char * pathname, mode_t mode, dev_t dev))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
-    debug("mknod(\"%s\", 0%od, %ld)", pathname, mode, dev);
-    expand_chroot_path(pathname, fakechroot_path, fakechroot_buf);
+    debug("mknod(\"%s\", 0%o, %ld)", pathname, mode, dev);
+    expand_chroot_path(pathname);
     return nextcall(mknod)(pathname, mode, dev);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
