@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,11 @@
 
 wrapper(opendir, DIR *, (const char * name))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("opendir(\"%s\")", name);
-    expand_chroot_path(name, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(name);
     return nextcall(opendir)(name);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
