@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -29,13 +29,14 @@
 wrapper(renameat, int, (int olddirfd, const char * oldpath, int newdirfd, const char * newpath))
 {
     char tmp[FAKECHROOT_PATH_MAX];
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("renameat(%d, \"%s\", %d, \"%s\")", olddirfd, oldpath, newdirfd, newpath);
-    expand_chroot_path(oldpath, fakechroot_path, fakechroot_buf);
+    expand_chroot_path_at(olddirfd, oldpath);
     strcpy(tmp, oldpath);
     oldpath = tmp;
-    expand_chroot_path(newpath, fakechroot_path, fakechroot_buf);
+    expand_chroot_path_at(newdirfd, newpath);
     return nextcall(renameat)(olddirfd, oldpath, newdirfd, newpath);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
