@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,10 +27,11 @@
 
 wrapper(revoke, int, (const char * file))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("revoke(\"%s\")", file);
-    expand_chroot_path(file, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(file);
     return nextcall(revoke)(file);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
