@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,11 @@
 
 wrapper(scandir, int, (const char * dir, struct dirent *** namelist, SCANDIR_TYPE_ARG3(filter), SCANDIR_TYPE_ARG4(compar)))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("scandir(\"%s\", &namelist, &filter, &compar)", dir);
-    expand_chroot_path(dir, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(dir);
     return nextcall(scandir)(dir, namelist, filter, compar);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
