@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,10 +27,11 @@
 
 wrapper(setxattr, int, (const char * path, const char * name, const void * value, size_t size, int flags))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("setxattr(\"%s\", \"%s\", &value, %zd, %d)", path, name, size, flags);
-    expand_chroot_path(path, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(path);
     return nextcall(setxattr)(path, name, value, size, flags);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
