@@ -4,7 +4,7 @@
 
 int main (int argc, char* argv[]) {
     if (argc != 2) {
-        fprintf(stderr, "Usage: %s cmd arg\n", argv[0]);
+        fprintf(stderr, "Usage: %s cmd\n", argv[0]);
         exit(2);
     }
 
